==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkGenericGlyph3DFilter.java <==
// java wrapper for vtkGenericGlyph3DFilter object
//

package vtk;
import vtk.*;

public class vtkGenericGlyph3DFilter extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSourceData_2(vtkPolyData id0);
  public void SetSourceData(vtkPolyData id0)
    { SetSourceData_2(id0); }

  private native void SetSourceData_3(int id0,vtkPolyData id1);
  public void SetSourceData(int id0,vtkPolyData id1)
    { SetSourceData_3(id0,id1); }

  private native long GetSource_4(int id0);
  public vtkPolyData GetSource(int id0) {
    long temp = GetSource_4(id0);

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScaling_5(int id0);
  public void SetScaling(int id0)
    { SetScaling_5(id0); }

  private native void ScalingOn_6();
  public void ScalingOn()
    { ScalingOn_6(); }

  private native void ScalingOff_7();
  public void ScalingOff()
    { ScalingOff_7(); }

  private native int GetScaling_8();
  public int GetScaling()
    { return GetScaling_8(); }

  private native void SetScaleMode_9(int id0);
  public void SetScaleMode(int id0)
    { SetScaleMode_9(id0); }

  private native int GetScaleMode_10();
  public int GetScaleMode()
    { return GetScaleMode_10(); }

  private native void SetScaleModeToScaleByScalar_11();
  public void SetScaleModeToScaleByScalar()
    { SetScaleModeToScaleByScalar_11(); }

  private native void SetScaleModeToScaleByVector_12();
  public void SetScaleModeToScaleByVector()
    { SetScaleModeToScaleByVector_12(); }

  private native void SetScaleModeToScaleByVectorComponents_13();
  public void SetScaleModeToScaleByVectorComponents()
    { SetScaleModeToScaleByVectorComponents_13(); }

  private native void SetScaleModeToDataScalingOff_14();
  public void SetScaleModeToDataScalingOff()
    { SetScaleModeToDataScalingOff_14(); }

  private native String GetScaleModeAsString_15();
  public String GetScaleModeAsString()
    { return GetScaleModeAsString_15(); }

  private native void SetColorMode_16(int id0);
  public void SetColorMode(int id0)
    { SetColorMode_16(id0); }

  private native int GetColorMode_17();
  public int GetColorMode()
    { return GetColorMode_17(); }

  private native void SetColorModeToColorByScale_18();
  public void SetColorModeToColorByScale()
    { SetColorModeToColorByScale_18(); }

  private native void SetColorModeToColorByScalar_19();
  public void SetColorModeToColorByScalar()
    { SetColorModeToColorByScalar_19(); }

  private native void SetColorModeToColorByVector_20();
  public void SetColorModeToColorByVector()
    { SetColorModeToColorByVector_20(); }

  private native String GetColorModeAsString_21();
  public String GetColorModeAsString()
    { return GetColorModeAsString_21(); }

  private native void SetScaleFactor_22(double id0);
  public void SetScaleFactor(double id0)
    { SetScaleFactor_22(id0); }

  private native double GetScaleFactor_23();
  public double GetScaleFactor()
    { return GetScaleFactor_23(); }

  private native void SetRange_24(double id0,double id1);
  public void SetRange(double id0,double id1)
    { SetRange_24(id0,id1); }

  private native void SetRange_25(double id0[]);
  public void SetRange(double id0[])
    { SetRange_25(id0); }

  private native double[] GetRange_26();
  public double[] GetRange()
    { return GetRange_26(); }

  private native void SetOrient_27(int id0);
  public void SetOrient(int id0)
    { SetOrient_27(id0); }

  private native void OrientOn_28();
  public void OrientOn()
    { OrientOn_28(); }

  private native void OrientOff_29();
  public void OrientOff()
    { OrientOff_29(); }

  private native int GetOrient_30();
  public int GetOrient()
    { return GetOrient_30(); }

  private native void SetClamping_31(int id0);
  public void SetClamping(int id0)
    { SetClamping_31(id0); }

  private native void ClampingOn_32();
  public void ClampingOn()
    { ClampingOn_32(); }

  private native void ClampingOff_33();
  public void ClampingOff()
    { ClampingOff_33(); }

  private native int GetClamping_34();
  public int GetClamping()
    { return GetClamping_34(); }

  private native void SetVectorMode_35(int id0);
  public void SetVectorMode(int id0)
    { SetVectorMode_35(id0); }

  private native int GetVectorMode_36();
  public int GetVectorMode()
    { return GetVectorMode_36(); }

  private native void SetVectorModeToUseVector_37();
  public void SetVectorModeToUseVector()
    { SetVectorModeToUseVector_37(); }

  private native void SetVectorModeToUseNormal_38();
  public void SetVectorModeToUseNormal()
    { SetVectorModeToUseNormal_38(); }

  private native void SetVectorModeToVectorRotationOff_39();
  public void SetVectorModeToVectorRotationOff()
    { SetVectorModeToVectorRotationOff_39(); }

  private native String GetVectorModeAsString_40();
  public String GetVectorModeAsString()
    { return GetVectorModeAsString_40(); }

  private native void SetIndexMode_41(int id0);
  public void SetIndexMode(int id0)
    { SetIndexMode_41(id0); }

  private native int GetIndexMode_42();
  public int GetIndexMode()
    { return GetIndexMode_42(); }

  private native void SetIndexModeToScalar_43();
  public void SetIndexModeToScalar()
    { SetIndexModeToScalar_43(); }

  private native void SetIndexModeToVector_44();
  public void SetIndexModeToVector()
    { SetIndexModeToVector_44(); }

  private native void SetIndexModeToOff_45();
  public void SetIndexModeToOff()
    { SetIndexModeToOff_45(); }

  private native String GetIndexModeAsString_46();
  public String GetIndexModeAsString()
    { return GetIndexModeAsString_46(); }

  private native void SetGeneratePointIds_47(int id0);
  public void SetGeneratePointIds(int id0)
    { SetGeneratePointIds_47(id0); }

  private native int GetGeneratePointIds_48();
  public int GetGeneratePointIds()
    { return GetGeneratePointIds_48(); }

  private native void GeneratePointIdsOn_49();
  public void GeneratePointIdsOn()
    { GeneratePointIdsOn_49(); }

  private native void GeneratePointIdsOff_50();
  public void GeneratePointIdsOff()
    { GeneratePointIdsOff_50(); }

  private native void SetPointIdsName_51(String id0);
  public void SetPointIdsName(String id0)
    { SetPointIdsName_51(id0); }

  private native String GetPointIdsName_52();
  public String GetPointIdsName()
    { return GetPointIdsName_52(); }

  private native String GetInputScalarsSelection_53();
  public String GetInputScalarsSelection()
    { return GetInputScalarsSelection_53(); }

  private native void SelectInputScalars_54(String id0);
  public void SelectInputScalars(String id0)
    { SelectInputScalars_54(id0); }

  private native String GetInputVectorsSelection_55();
  public String GetInputVectorsSelection()
    { return GetInputVectorsSelection_55(); }

  private native void SelectInputVectors_56(String id0);
  public void SelectInputVectors(String id0)
    { SelectInputVectors_56(id0); }

  private native String GetInputNormalsSelection_57();
  public String GetInputNormalsSelection()
    { return GetInputNormalsSelection_57(); }

  private native void SelectInputNormals_58(String id0);
  public void SelectInputNormals(String id0)
    { SelectInputNormals_58(id0); }

  public vtkGenericGlyph3DFilter() { super(); }

  public vtkGenericGlyph3DFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-15-armv7h.pkg.tar.xz: vtk/vtkGenericGlyph3DFilter.java <==
// java wrapper for vtkGenericGlyph3DFilter object
//

package vtk;
import vtk.*;

public class vtkGenericGlyph3DFilter extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSourceData_2(vtkPolyData id0);
  public void SetSourceData(vtkPolyData id0)
    { SetSourceData_2(id0); }

  private native void SetSourceData_3(int id0,vtkPolyData id1);
  public void SetSourceData(int id0,vtkPolyData id1)
    { SetSourceData_3(id0,id1); }

  private native long GetSource_4(int id0);
  public vtkPolyData GetSource(int id0) {
    long temp = GetSource_4(id0);

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScaling_5(int id0);
  public void SetScaling(int id0)
    { SetScaling_5(id0); }

  private native void ScalingOn_6();
  public void ScalingOn()
    { ScalingOn_6(); }

  private native void ScalingOff_7();
  public void ScalingOff()
    { ScalingOff_7(); }

  private native int GetScaling_8();
  public int GetScaling()
    { return GetScaling_8(); }

  private native void SetScaleMode_9(int id0);
  public void SetScaleMode(int id0)
    { SetScaleMode_9(id0); }

  private native int GetScaleMode_10();
  public int GetScaleMode()
    { return GetScaleMode_10(); }

  private native void SetScaleModeToScaleByScalar_11();
  public void SetScaleModeToScaleByScalar()
    { SetScaleModeToScaleByScalar_11(); }

  private native void SetScaleModeToScaleByVector_12();
  public void SetScaleModeToScaleByVector()
    { SetScaleModeToScaleByVector_12(); }

  private native void SetScaleModeToScaleByVectorComponents_13();
  public void SetScaleModeToScaleByVectorComponents()
    { SetScaleModeToScaleByVectorComponents_13(); }

  private native void SetScaleModeToDataScalingOff_14();
  public void SetScaleModeToDataScalingOff()
    { SetScaleModeToDataScalingOff_14(); }

  private native String GetScaleModeAsString_15();
  public String GetScaleModeAsString()
    { return GetScaleModeAsString_15(); }

  private native void SetColorMode_16(int id0);
  public void SetColorMode(int id0)
    { SetColorMode_16(id0); }

  private native int GetColorMode_17();
  public int GetColorMode()
    { return GetColorMode_17(); }

  private native void SetColorModeToColorByScale_18();
  public void SetColorModeToColorByScale()
    { SetColorModeToColorByScale_18(); }

  private native void SetColorModeToColorByScalar_19();
  public void SetColorModeToColorByScalar()
    { SetColorModeToColorByScalar_19(); }

  private native void SetColorModeToColorByVector_20();
  public void SetColorModeToColorByVector()
    { SetColorModeToColorByVector_20(); }

  private native String GetColorModeAsString_21();
  public String GetColorModeAsString()
    { return GetColorModeAsString_21(); }

  private native void SetScaleFactor_22(double id0);
  public void SetScaleFactor(double id0)
    { SetScaleFactor_22(id0); }

  private native double GetScaleFactor_23();
  public double GetScaleFactor()
    { return GetScaleFactor_23(); }

  private native void SetRange_24(double id0,double id1);
  public void SetRange(double id0,double id1)
    { SetRange_24(id0,id1); }

  private native void SetRange_25(double id0[]);
  public void SetRange(double id0[])
    { SetRange_25(id0); }

  private native double[] GetRange_26();
  public double[] GetRange()
    { return GetRange_26(); }

  private native void SetOrient_27(int id0);
  public void SetOrient(int id0)
    { SetOrient_27(id0); }

  private native void OrientOn_28();
  public void OrientOn()
    { OrientOn_28(); }

  private native void OrientOff_29();
  public void OrientOff()
    { OrientOff_29(); }

  private native int GetOrient_30();
  public int GetOrient()
    { return GetOrient_30(); }

  private native void SetClamping_31(int id0);
  public void SetClamping(int id0)
    { SetClamping_31(id0); }

  private native void ClampingOn_32();
  public void ClampingOn()
    { ClampingOn_32(); }

  private native void ClampingOff_33();
  public void ClampingOff()
    { ClampingOff_33(); }

  private native int GetClamping_34();
  public int GetClamping()
    { return GetClamping_34(); }

  private native void SetVectorMode_35(int id0);
  public void SetVectorMode(int id0)
    { SetVectorMode_35(id0); }

  private native int GetVectorMode_36();
  public int GetVectorMode()
    { return GetVectorMode_36(); }

  private native void SetVectorModeToUseVector_37();
  public void SetVectorModeToUseVector()
    { SetVectorModeToUseVector_37(); }

  private native void SetVectorModeToUseNormal_38();
  public void SetVectorModeToUseNormal()
    { SetVectorModeToUseNormal_38(); }

  private native void SetVectorModeToVectorRotationOff_39();
  public void SetVectorModeToVectorRotationOff()
    { SetVectorModeToVectorRotationOff_39(); }

  private native String GetVectorModeAsString_40();
  public String GetVectorModeAsString()
    { return GetVectorModeAsString_40(); }

  private native void SetIndexMode_41(int id0);
  public void SetIndexMode(int id0)
    { SetIndexMode_41(id0); }

  private native int GetIndexMode_42();
  public int GetIndexMode()
    { return GetIndexMode_42(); }

  private native void SetIndexModeToScalar_43();
  public void SetIndexModeToScalar()
    { SetIndexModeToScalar_43(); }

  private native void SetIndexModeToVector_44();
  public void SetIndexModeToVector()
    { SetIndexModeToVector_44(); }

  private native void SetIndexModeToOff_45();
  public void SetIndexModeToOff()
    { SetIndexModeToOff_45(); }

  private native String GetIndexModeAsString_46();
  public String GetIndexModeAsString()
    { return GetIndexModeAsString_46(); }

  private native void SetGeneratePointIds_47(int id0);
  public void SetGeneratePointIds(int id0)
    { SetGeneratePointIds_47(id0); }

  private native int GetGeneratePointIds_48();
  public int GetGeneratePointIds()
    { return GetGeneratePointIds_48(); }

  private native void GeneratePointIdsOn_49();
  public void GeneratePointIdsOn()
    { GeneratePointIdsOn_49(); }

  private native void GeneratePointIdsOff_50();
  public void GeneratePointIdsOff()
    { GeneratePointIdsOff_50(); }

  private native void SetPointIdsName_51(String id0);
  public void SetPointIdsName(String id0)
    { SetPointIdsName_51(id0); }

  private native String GetPointIdsName_52();
  public String GetPointIdsName()
    { return GetPointIdsName_52(); }

  private native String GetInputScalarsSelection_53();
  public String GetInputScalarsSelection()
    { return GetInputScalarsSelection_53(); }

  private native void SelectInputScalars_54(String id0);
  public void SelectInputScalars(String id0)
    { SelectInputScalars_54(id0); }

  private native String GetInputVectorsSelection_55();
  public String GetInputVectorsSelection()
    { return GetInputVectorsSelection_55(); }

  private native void SelectInputVectors_56(String id0);
  public void SelectInputVectors(String id0)
    { SelectInputVectors_56(id0); }

  private native String GetInputNormalsSelection_57();
  public String GetInputNormalsSelection()
    { return GetInputNormalsSelection_57(); }

  private native void SelectInputNormals_58(String id0);
  public void SelectInputNormals(String id0)
    { SelectInputNormals_58(id0); }

  public vtkGenericGlyph3DFilter() { super(); }

  public vtkGenericGlyph3DFilter(long id) { super(id); }
  public native long   VTKInit();

}
